<p align="center">
  <img src="https://raw.githubusercontent.com/rk4bir/USCodeKit/refs/heads/main/docs/logo.png" alt="USCodeKit_logo" width="200"/>
</p>

<h1 align="center">USCodeKit</h1>

<p align="center">
  <img src="https://raw.githubusercontent.com/rk4bir/USCodeKit/887586931b051e04e47cae67e97883324813a7cf/docs/coverage.svg" alt="Coverage"/>
</p>

# USCodeKit

> A comprehensive package that includes all the essential tools commonly used for US phone, zip code info, NAICS (2022), (upcoming more...)

## Docs

> [Hosted Docs](https://rk4bir.github.io/USCodeKit/)

- [Installation](https://rk4bir.github.io/USCodeKit/#installation)
- [Getting Started](https://rk4bir.github.io/USCodeKit/)
- **Modules**
  - [phone](https://rk4bir.github.io/USCodeKit/phone/)
  - [zip_code](https://rk4bir.github.io/USCodeKit/zip_code/)
  - [NAICS (2022)](https://rk4bir.github.io/USCodeKit/naics/)

## Installation

Using `pip`

```bash
pip install uscodekit
```

Using `poetry`

```bash
poetry add uscodekit
```
